<?php

$dbhost = "localhost";
$dbuser = "alphpwcp_user";
$dbpassword = "purebliss3030@";
$dbdatabase = "alphpwcp_db";
$config_basedir = "";

$config_sitename = "Alpha Chequers";
$adminemail = "support@alphachequers.com";

?>
